@@ -27,6 +27,7 @@ Features
 * In-built and cusomizable limit to protect against frequent API calls
 * Local file-based storage for frequent requests (persistent cache)
 
+
 @author: Hrishikesh Terdalkar
 """
 
@@ -49,6 +50,27 @@ FREQ_LOW = 10
 FREQ_MEDIUM = 20
 FREQ_HIGH = 30
 
+FANTASY = {
+    'kills': 0.3,
+    'deaths': -0.3,
+    'assists': 0.15,
+    'last_hits': 0.003,
+    'gold_per_min': 0.002,
+    'xp_per_min': 0.002,
+    'tower_kills': 1,
+    'roshan_kills': 1,
+    'teamfight': 3,
+    'wards_placed': 0.5,
+    'camps_stacked': 0.5,
+    'runes_grabbed': 0.25,
+    'first_blood': 4,
+    'stuns': 0.07,
+    'hero_healing': 0.0004,
+
+    # Add '_base' suffix to the parameter for specifying base score
+    'deaths_base': 3,
+}
+
 ###############################################################################
 
 
@@ -77,15 +99,30 @@ class OpenDota:
             prevent hitting the daily API limit.
             If you have an API key, this value is ignored.
             The default is 3.
+        fantasy: dict, (optional)
+            Fantasy DotA2 Configuration
+            Utility constant FANTASY holds the standard values
+            and is used as default.
+            Keys of the fantasy must match those of FANTASY.
+
+            Parameters ending with `_base` are used as base values,
+            while others are used as multipliers.
+            e.g.
+                `deaths` = -0.3
+                `deaths_base` = 3
+            results in the calculation as follows,
+                `death_score` = 3 + (number_of_deaths * -0.3)
+            If `_base` parameter is absent, it's assumed to be 0.
         api_url: str, (optional)
             URL to OpenDota API.
             It is recommended to not change this value.
     """
 
     data_dir: str = attr.ib(default=None)
-    api_url: str = attr.ib(default="https://api.opendota.com/api", repr=False)
     api_key: str = attr.ib(default=None, repr=False)
     delay: int = attr.ib(default=3, repr=False)
+    fantasy: dict = attr.ib(default=FANTASY, repr=False)
+    api_url: str = attr.ib(default="https://api.opendota.com/api", repr=False)
 
     def __attrs_post_init__(self):
         self._session = requests.Session()
@@ -98,7 +135,8 @@ class OpenDota:
     # ----------------------------------------------------------------------- #
 
     def request(self, url, *, post=False, data={}, filename=None, force=False):
-        """Make a GET or POST request to <OPENDOTA/> API
+        """
+        Make a GET or POST request to <OPENDOTA/> API
 
         Parameters
         ----------
@@ -343,7 +381,7 @@ class OpenDota:
     # Matches
 
     def get_match(self, match_id, force=False):
-        """"Get match data"""
+        """Get match data"""
         url = f"/matches/{match_id}"
         filename = f"match_{match_id}.json"
         return self.get(url, filename=filename, force=force)
@@ -466,11 +504,93 @@ class OpenDota:
         data = {"q": search_key}
         return self.get(url, data=data)
 
+    # ----------------------------------------------------------------------- #
+    # Fantasy
+
+    def get_fantasy_points(self, match_id, force=False):
+        """
+        Get Fantasy Points of All Players from a Match
+
+        Returns
+        -------
+            list:
+                List of fantasy profiles of players from the specified match
+        """
+        match = self.get_match(match_id, force=force)
+        fantasy_points = []
+
+        for player in match['players']:
+            player_fantasy = {
+                'player_slot': player['player_slot'],
+                'account_id': player['account_id'],
+                'fantasy': {
+                    'kills': {
+                        'value': player['kills']
+                    },
+                    'deaths': {
+                        'value': player['deaths']
+                    },
+                    'assists': {
+                        'value': player['assists']
+                    },
+                    'last_hits': {
+                        'value': player['last_hits'] + player['denies'],
+                    },
+                    'gold_per_min': {
+                        'value': player['gold_per_min']
+                    },
+                    'xp_per_min': {
+                        'value': player['xp_per_min']
+                    },
+                    'tower_kills': {
+                        'value': player['tower_kills']
+                    },
+                    'roshan_kills': {
+                        'value': player['roshan_kills']
+                    },
+                    'teamfight': {
+                        'value': player['teamfight_participation']
+                    },
+                    'wards_placed': {
+                        'value': player['obs_placed']
+                    },
+                    'camps_stacked': {
+                        'value': player['camps_stacked']
+                    },
+                    'runes_grabbed': {
+                        'value': player['rune_pickups']
+                    },
+                    'first_blood': {
+                        'value': int(player['firstblood_claimed'])
+                    },
+                    'stuns': {
+                        'value': player['stuns']
+                    },
+                    'hero_healing': {
+                        'value': player['hero_healing']
+                    }
+                },
+            }
+
+            for param, obj in player_fantasy['fantasy'].items():
+                obj['score'] = (
+                    self.fantasy.get(f'{param}_base', 0) +
+                    self.fantasy[param] * obj['value']
+                )
+            player_fantasy['total_score'] = sum([
+                obj['score']
+                for obj in player_fantasy['fantasy'].values()
+            ])
+            fantasy_points.append(player_fantasy)
+
+        return fantasy_points
+
     # ----------------------------------------------------------------------- #
     # Database
 
     def get_schema(self, table_name=None, force=False):
-        """Get database schema
+        """
+        Get database schema
 
         Parameters
         ----------
@@ -507,15 +627,16 @@ class OpenDota:
     # ----------------------------------------------------------------------- #
 
     def update_data(self, frequency=FREQ_HIGH):
-        """Update core data
-
-        It is recommended to use utility constants, FREQ_LOW, FREQ_MEDIUM or
-        FREQ_HIGH to specifcy frequency.
+        """
+        Update core data
 
         Parameters
         ----------
             frequency: int
-                FREQ_HIGH: update data that only changes frequently
+                It is recommended to use utility constants,
+                FREQ_LOW, FREQ_MEDIUM or FREQ_HIGH to specifcy frequency.
+
+                FREQ_HIGH: update data that changes frequently
                    (e.g. teams)
                 FREQ_MEDIUM: update data that changes with a moderate frequency
                    (e.g. hero benchmarks)
